@@ -1,5 +1,5 @@
 """Utilities for computer vision."""
 
 from .imgio import *
-from .types import *
+from .cvtypes import *
 from .videoio import *
